searchData={"items":[{"type":"module","title":"Commandline.CLI","doc":"Command line interface for checking payment card account number brands.\n\nBuild using mix escript.build from project root.","ref":"Commandline.CLI.html"},{"type":"module","title":"Examples - Commandline.CLI","doc":"iex> ./simplecardbrand 41111111111111111\n    PAN: 41111111111111111 -> Unknown card brand.\n\n    iex> ./simplecardbrand 4111111111111111 7111111111111111 8331111111111111111\n    PAN: 4111111111111111 -> Unknown card brand.\n    PAN: 7111111111111111 -> Brand: gpn\n    PAN: 8331111111111111111 -> Unknown card brand.\n\n    iex> ./simplecardbrand 4111111 --pan-length=16\n    PAN: 4111111 -> Brand: visa","ref":"Commandline.CLI.html#module-examples"},{"type":"function","title":"Commandline.CLI.main/1","doc":"Entry point.\n\nSee module documentation for usage.","ref":"Commandline.CLI.html#main/1"},{"type":"module","title":"SimpleCardBrand","doc":"Identify the card brand from the PAN or the first six or  eight (UkrCard) PAN digits.\nThe PAN must contain only digits without leading or trailing spaces.\n\nSupports:\n- American Express (:americanexpress)\n- BORICA (:borica)\n- China T-Union (:chinatunion)\n- China UnionPay (:chinaunionpay)\n- Dankort (:dankort)\n- Diners Club (:dinersclub)\n- Diners Club International (:dinersclubinternational)\n- Discover (:discover)\n- GPN (:gpn)\n- Humo (:humo)\n- InstaPayment (:instapayment)\n- InterPayment (:interpayment)\n- JCB: (:jcb)\n- LankaPay: (:lankapay)\n- Maestro (:maestro)\n- Maestro UK (:maestrouk)\n- Mastercard (:mastercard)\n- Mir (:mir)\n- Napas (:napas)\n- RuPay (:rupay)\n- Troy (:troy)\n- UATP (:uatp)\n- UkrCard (:ukrcard)\n- UzCard (:uzcard)\n- Verve (:verve)\n- Visa (:visa)\n- Visa Electron (:visaelectron)\n\nRules as per: https://en.wikipedia.org/wiki/Payment_card_number","ref":"SimpleCardBrand.html"},{"type":"function","title":"SimpleCardBrand.card_brand/1","doc":"Identify the card brand from the `pan`.","ref":"SimpleCardBrand.html#card_brand/1"},{"type":"function","title":"Examples - SimpleCardBrand.card_brand/1","doc":"iex> SimpleCardBrand.card_brand(\"4111111111111111\")\n    {:ok, :visa}\n\n    iex> SimpleCardBrand.card_brand(\"6040010012121161819\")\n    {:ok, :ukrcard}\n\n    iex> SimpleCardBrand.card_brand(\"5060994444444416\")\n    {:ok, :verve}\n\n    iex> SimpleCardBrand.card_brand(\"41111111111\")\n    {:error, {:pan_too_short, \"Minimum PAN length is 12, found 11.\"}}\n\n    iex> SimpleCardBrand.card_brand(\"41111111111111111120\")\n    {:error, {:pan_too_long, \"Maximum PAN length is 19, found 20.\"}}","ref":"SimpleCardBrand.html#card_brand/1-examples"},{"type":"function","title":"SimpleCardBrand.card_brand/2","doc":"Identify the card brand from a full or partial `pan` and the actual PAN length.\nUseful when identifying brands from previously-stored PANs.\n\nCheck for UkrCard and Verve early.","ref":"SimpleCardBrand.html#card_brand/2"},{"type":"function","title":"Examples - SimpleCardBrand.card_brand/2","doc":"iex> SimpleCardBrand.card_brand(\"411111\", 16)\n    {:ok, :visa}\n\n    iex> SimpleCardBrand.card_brand(\"6040010012\", 18)\n    {:ok, :ukrcard}\n\n    iex> SimpleCardBrand.card_brand(\"50609944444\", 19)\n    {:ok, :verve}\n\n    iex> SimpleCardBrand.card_brand(\"4111111111111111\", 10)\n    {:error, {:pan_too_short,\"Minimum PAN length is 12, found 10.\"}}\n\n    iex> SimpleCardBrand.card_brand(\"0123456789012345678\")\n    {:error, {:pan_unknown,\"Unknown card brand.\"}}","ref":"SimpleCardBrand.html#card_brand/2-examples"},{"type":"module","title":"SimpleCardBrand.Guards","doc":"Guard macros.\n\nNOTE: defguard is a macro so the doc tests do not run.","ref":"SimpleCardBrand.Guards.html"},{"type":"macro","title":"SimpleCardBrand.Guards.is_ukrcard/1","doc":"Compare the first eight (8) digits of the `pan` against the UkrCard range.\nUse in guards where `pan` is known to be bytes.","ref":"SimpleCardBrand.Guards.html#is_ukrcard/1"},{"type":"macro","title":"Examples - SimpleCardBrand.Guards.is_ukrcard/1","doc":"iex> SimpleCardBrand.Guards.is_ukrcard(\"60420099123212\")\n    true\n\n    iex> SimpleCardBrand.Guards.is_ukrcard(\"6042010022222\")\n    false","ref":"SimpleCardBrand.Guards.html#is_ukrcard/1-examples"},{"type":"macro","title":"SimpleCardBrand.Guards.is_verve/1","doc":"Compare the first six (6) digits of the `pan` against the Verve brand range.\nUse in guards where `pan` is known to be bytes.","ref":"SimpleCardBrand.Guards.html#is_verve/1"},{"type":"macro","title":"Examples - SimpleCardBrand.Guards.is_verve/1","doc":"iex> SimpleCardBrand.Guards.is_verve(\"506099212121\")\n    true\n\n    iex> SimpleCardBrand.Guards.is_verve(\"50609123\")\n    false","ref":"SimpleCardBrand.Guards.html#is_verve/1-examples"},{"type":"macro","title":"SimpleCardBrand.Guards.pan_range/3","doc":"Check the PAN length is in the minimum to maximum allowed length (inclusive).\nUse in guards where `pan_length` is known to be an integer.","ref":"SimpleCardBrand.Guards.html#pan_range/3"},{"type":"macro","title":"Examples - SimpleCardBrand.Guards.pan_range/3","doc":"iex> SimpleCardBrand.Guards.pan_range(16, 12, 19)\n    true\n\n    iex> SimpleCardBrand.Guards.pan_range(16, 19, 19)\n    false","ref":"SimpleCardBrand.Guards.html#pan_range/3-examples"},{"type":"extras","title":"CHANGELOG","doc":"# CHANGELOG","ref":"changelog.html"},{"type":"extras","title":"1.0.1 -- 2023-09-08 - CHANGELOG","doc":"#","ref":"changelog.html#1-0-1-2023-09-08"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Test guards.\n- Test CLI module.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Remove code that maps PAN starting with 65 to :rupay.\n  PAN starting with 65 is Discover.\n\n- CI changes:\n  - Elixir 1.14.5\n  - OTP 25.3.2.5\n  - Add Elixir 1.15.5\n  - Add OTP 26.0.2\n\n- Code Quality Changes (Adopting Elixir):\n  - Credo config\n  - Document dialyzer\n  - InchEx\n  - ExCoveralls\n  - Sobelow\n\n- Update dependencies:\n  - `dialyxir`\n  - `ex_doc`","ref":"changelog.html#changed"},{"type":"extras","title":"1.0.0 -- 2023-08-08 - CHANGELOG","doc":"Publish\n\n#","ref":"changelog.html#1-0-0-2023-08-08"},{"type":"extras","title":"Added - CHANGELOG","doc":"- CLI for `card_brand/2`.\n- Add GitHub workflow.","ref":"changelog.html#added"},{"type":"extras","title":"0.3.0 - 2023-08-08 - CHANGELOG","doc":"#","ref":"changelog.html#0-3-0-2023-08-08"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Add README and CHANGELOG to Hex docs.\n- Add pre-commit tasks.\n- Add command-line interface.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Return reason tuple on error.\n  - `{:error, {:pan_too_short,\"Minimum PAN length is 12, found 10.\"}}`\n  - `{:error, {:pan_unknown,\"Unknown card brand.\"}}`\n  - `{:error, {:pan_too_long, \"Maximum PAN length is 19, found 20.\"}}`\n- Replace Erlang binary/bytes types with String.t in @spec's.","ref":"changelog.html#changed"},{"type":"extras","title":"0.2.0 - 2023-08-07 WIP - CHANGELOG","doc":"#","ref":"changelog.html#0-2-0-2023-08-07-wip"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Brands: Dankort, GPN, LankaPay, Troy, UkrCard, Verve.\n  - Brands are now complete.\n- In-line document tests.\n- Generate documentation.\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Correct major error of `card_brand/1` passing CodePoints to `card_brand/2`.\n- Identify PAN starting just 65 as Discover, vs. RuPay or Troy.\n- Minor credo refactors.","ref":"changelog.html#changed"},{"type":"extras","title":"v0.1.0 - 2023-08-05 WIP - CHANGELOG","doc":"#","ref":"changelog.html#v0-1-0-2023-08-05-wip"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Add guards to `card_brand`.\n- Rough move to mix project, tests are functional.","ref":"changelog.html#added"},{"type":"extras","title":"v0.0.3 - 2023-08-04 WIP - CHANGELOG","doc":"#","ref":"changelog.html#v0-0-3-2023-08-04-wip"},{"type":"extras","title":"Added - CHANGELOG","doc":"- Make `pan_length` first parameter of `pan_range`.\n- China UnionPay, China T-Union, Diners Club, Diners Club International\n- JCB, Maestro, Maestro UK, Visa Electron\n- BORICA, Humo, InstaPayment, InterPayment, Mir, Napas, UATP, UzCard","ref":"changelog.html#added"},{"type":"extras","title":"v0.0.2 - 2023-08-03 WIP - CHANGELOG","doc":"- Initial release.\n\n#","ref":"changelog.html#v0-0-2-2023-08-03-wip"},{"type":"extras","title":"Added - CHANGELOG","doc":"- American Express, Discover, Mastercard, and Visa.","ref":"changelog.html#added"},{"type":"extras","title":"Simple Card Brand","doc":"# Simple Card Brand\n\nDetermine a payment card's brand from the leading digits and length of the account number (PAN).\n\nUses the rules documented on [Wikipedia](https://en.wikipedia.org/wiki/Payment_card_number).","ref":"readme.html"},{"type":"extras","title":"Card Brands - Simple Card Brand","doc":"- American Express (:americanexpress)\n- BORICA (:borica)\n- China T-Union (:chinatunion)\n- China UnionPay (:chinaunionpay)\n- Dankort (:dankort)\n- Diners Club (:dinersclub)\n- Diners Club International (:dinersclubinternational)\n- Discover (:discover)\n- GPN (:gpn)\n- Humo (:humo)\n- InstaPayment (:instapayment)\n- InterPayment (:interpayment)\n- JCB: (:jcb)\n- LankaPay: (:lankapay)\n- Maestro (:maestro)\n- Maestro UK (:maestrouk)\n- Mastercard (:mastercard)\n- Mir (:mir)\n- Napas (:napas)\n- RuPay (:rupay)\n- Troy (:troy)\n- UATP (:uatp)\n- UkrCard (:ukrcard)\n- UzCard (:uzcard)\n- Verve (:verve)\n- Visa (:visa)\n- Visa Electron (:visaelectron)\n\n#","ref":"readme.html#card-brands"},{"type":"extras","title":"Conflicts - Simple Card Brand","doc":"The [Wikipedia](https://en.wikipedia.org/wiki/Payment_card_number) page has several account number range conflicts that need to be researched.\n\n- 65 is always recognized as Discover.\n  Overrides RuPay and Troy.\n\n- 6759 is documented as both Maestro and Maestro UK.\n  - Recognized as Maestro UK.\n\n- 54 is documented as both Diners Club in the US and Mastercard.\n  - Recognized as Diners Club.","ref":"readme.html#conflicts"},{"type":"extras","title":"Mix Commands - Simple Card Brand","doc":"- mix format\n- mix test\n- mix coveralls.html\n- mix credo --strict\n- mix dialyzer\n- mix inch\n  - Documentation coverage test.\n  - Use as guidance, not pass/fail CI.\n  - Fails to note documentation on new `defguard` macro.\n- mix hex.outdated\n- mix hex.audit\n- mix deps.update XXX\n- mix sobelow --config\n  - Better suited for Phoenix apps. Included for future reference.","ref":"readme.html#mix-commands"},{"type":"extras","title":"Installation - Simple Card Brand","doc":"TO DO\n\nIf [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `simplecardbrand` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simplecardbrand, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Adopting Elixir - Simple Card Brand","doc":"I'm using this project as a reference for various quality control tools.\nAs a result, there's a lot of code quality tools for such a small single-file module.\nUsing the [Adopting Elixir](https://www.kobo.com/us/en/ebook/adopting-elixir) recommendations.","ref":"readme.html#adopting-elixir"}],"content_type":"text/markdown"}